﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Drawing.Imaging;

namespace rosskyru
{
    public partial class FormForTray : Form
    {
        /// <summary>
        /// конструктор формы
        /// </summary>
        public FormForTray()
        {
            InitializeComponent();
            //задаем всплывающий текст-подсказку (появляется при наведении указателя на иконку в трее)
            _notifyIcon.Text = "[Rossky.ru]";
            //устанавливаем значок, отображаемый в трее:
            _notifyIcon.Icon = _myIcon;
            //подписываемся на событие клика мышкой по значку в трее
            _notifyIcon.MouseClick += new MouseEventHandler(_notifyIcon_MouseClick);
            //подписываемся на событие изменения размера формы
            this.Resize += new EventHandler(FormForTray_Resize);

            //подписываемся на событие тика таймера
            _timer.Tick += new EventHandler(_timer_Tick);

            //добавляем контекстное меню к значку
            _notifyIcon.ContextMenuStrip = _contextMenuStrip;
            //подписываемся на событие клика по пункту меню "Выход"
            _exitToolStripMenuItem.Click += new EventHandler(_exitToolStripMenuItem_Click);

            //создаем битмапку 16х16
            Bitmap bmp = new Bitmap(16, 16);
            //задаем шрифт и его размеры
            Font font = new Font(FontFamily.GenericSansSerif, 10F);
            //создаем объект класса для рисования "из картинки"
            Graphics graphics = Graphics.FromImage(bmp);
            //создаем кисть для прозрачного фона
            SolidBrush whiteBrush = new SolidBrush(Color.FromArgb(0, 1, 1, 1));
            //красной кистью будем писать буквы
            SolidBrush redBrush = new SolidBrush(Color.Red);

            //создаем прямоугольник 16х16 с начальными координатами (0,0)
            RectangleF canvas = new RectangleF(0, 0, 16, 16);
            //закрашиваем его "фоновой" кистью
            graphics.FillRectangle(whiteBrush, canvas);
            //пишем в нем заданную букву красной кистью
            graphics.DrawString("R", font, redBrush, canvas);
            //преобразуем картинку bmp в иконку
            Icon icon = Icon.FromHandle(bmp.GetHicon());

            //уже привычно задаем начальную картинку
            _notifyIcon.Icon = icon;
            //добавляем сознанную иконку в массив, чтобы каждый раз не создавать её заново
            icc[0] = icon;
            icc[7] = icon; 

            //снова "затираем" картинку прозрачным цветом
            graphics.Clear(Color.FromArgb(0, 1, 1, 1));
            graphics.DrawString("O", font, redBrush, canvas);
            icon = Icon.FromHandle(bmp.GetHicon());
            icc[1] = icon;

            graphics.Clear(Color.FromArgb(0, 1, 1, 1));
            graphics.FillRectangle(whiteBrush, canvas);
            graphics.DrawString("S", font, redBrush, canvas);
            icon = Icon.FromHandle(bmp.GetHicon());
            icc[2] = icon;
            icc[3] = icon;

            graphics.Clear(Color.FromArgb(0, 1, 1, 1));
            graphics.FillRectangle(whiteBrush, canvas);
            graphics.DrawString("K", font, redBrush, canvas);
            icon = Icon.FromHandle(bmp.GetHicon());
            icc[4] = icon;

            graphics.Clear(Color.FromArgb(0, 1, 1, 1));
            graphics.FillRectangle(whiteBrush, canvas);
            graphics.DrawString("Y", font, redBrush, canvas);
            icon = Icon.FromHandle(bmp.GetHicon());
            icc[5] = icon;

            graphics.Clear(Color.FromArgb(0, 1, 1, 1));
            graphics.FillRectangle(whiteBrush, canvas);
            graphics.DrawString(".", font, redBrush, canvas);
            icon = Icon.FromHandle(bmp.GetHicon());
            icc[6] = icon;

            graphics.Clear(Color.FromArgb(0, 1, 1, 1));
            graphics.FillRectangle(whiteBrush, canvas);
            graphics.DrawString("U", font, redBrush, canvas);
            icon = Icon.FromHandle(bmp.GetHicon());
            icc[8] = icon;
        }
        /// <summary>
        /// массив для созданных иконок
        /// </summary>
        private Icon[] icc = new Icon[9];
        /// <summary>
        /// начальный индекс для отображения элементов из массива
        /// </summary>
        private int iii = 0;

        /// <summary>
        /// обрабатываем клик по кнопке выхода - завершаем работу приложения
        /// </summary>
        void _exitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Application.Exit();
        }

        /// <summary>
        /// флаг для организации мигания
        /// </summary>
        private bool _forBlinking = false;
        /// <summary>
        /// обрабатываем тик
        /// </summary>
        void _timer_Tick(object sender, EventArgs e)
        {
            _notifyIcon.Icon = icc[iii];
            iii++;
            if (iii == 9)
                iii = 0;
        }

        /// <summary>
        /// наша иконка
        /// </summary>
        private Icon _myIcon = new Icon("favicon.ico");
        /// <summary>
        /// "пустая" иконка
        /// </summary>
        private Icon _myEmptyIcon = new Icon("emptyicon.ico");

        /// <summary>
        /// здесь хранится состояние окна до сворачивания (максимизированное или нормальное)
        /// </summary>
        private FormWindowState _OldFormState;

        /// <summary>
        /// обрабатываем событие клика мышью по значку в трее
        /// </summary>
        void _notifyIcon_MouseClick(object sender, MouseEventArgs e)
        {
            //проверяем, какой кнопкой было произведено нажатие
            if (e.Button == MouseButtons.Left)//если левой кнопкой мыши
            {
                //проверяем текущее состояние окна
                if (WindowState == FormWindowState.Normal || WindowState == FormWindowState.Maximized)//если оно развернуто
                {
                    //сохраняем текущее состояние
                    _OldFormState = WindowState;
                    //сворачиваем окно
                    WindowState = FormWindowState.Minimized;
                    //скрываться в трей оно будет по событию Resize (изменение размера), которое сгенерировалось после минимизации строчкой выше               
                }
                else//в противном случае
                {
                    //и показываем на нанели задач
                    Show();
                    //разворачиваем (возвращаем старое состояние "до сворачивания")
                    WindowState = _OldFormState;
                }
            }
        }

        /// <summary>
        /// обрабатываем событие изменения размера
        /// </summary>
        void FormForTray_Resize(object sender, EventArgs e)
        {
            if (FormWindowState.Minimized == WindowState)//если окно "свернуто"
            {
                //то скрываем его
                Hide();
            }
        }
    }
}

